@@ -26,20 +26,19 @@ class UpdateNamespaceVpcRequest(RoaRequest):
 		RoaRequest.__init__(self, 'sae', '2019-05-06', 'UpdateNamespaceVpc','serverless')
 		self.set_uri_pattern('/pop/v1/sam/namespace/updateNamespaceVpc')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_NamespaceId(self):
+	def get_NamespaceId(self): # String
 		return self.get_query_params().get('NamespaceId')
 
-	def set_NamespaceId(self,NamespaceId):
-		self.add_query_param('NamespaceId',NamespaceId)
-
-	def get_VpcId(self):
+	def set_NamespaceId(self, NamespaceId):  # String
+		self.add_query_param('NamespaceId', NamespaceId)
+	def get_VpcId(self): # String
 		return self.get_query_params().get('VpcId')
 
-	def set_VpcId(self,VpcId):
-		self.add_query_param('VpcId',VpcId)
\ No newline at end of file
+	def set_VpcId(self, VpcId):  # String
+		self.add_query_param('VpcId', VpcId)
